==> openshift-model-operator-6.9.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/AdditionalNetworkDefinitionFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AdditionalNetworkDefinitionFluent<A extends AdditionalNetworkDefinitionFluent<A>> extends BaseFluent<A>{
  public AdditionalNetworkDefinitionFluent() {
  }
  
  public AdditionalNetworkDefinitionFluent(AdditionalNetworkDefinition instance) {
    this.copyInstance(instance);
  }
  private String name;
  private String namespace;
  private String rawCNIConfig;
  private SimpleMacvlanConfigBuilder simpleMacvlanConfig;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(AdditionalNetworkDefinition instance) {
    instance = (instance != null ? instance : new AdditionalNetworkDefinition());
    if (instance != null) {
          this.withName(instance.getName());
          this.withNamespace(instance.getNamespace());
          this.withRawCNIConfig(instance.getRawCNIConfig());
          this.withSimpleMacvlanConfig(instance.getSimpleMacvlanConfig());
          this.withType(instance.getType());
          this.withName(instance.getName());
          this.withNamespace(instance.getNamespace());
          this.withRawCNIConfig(instance.getRawCNIConfig());
          this.withSimpleMacvlanConfig(instance.getSimpleMacvlanConfig());
          this.withType(instance.getType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getNamespace() {
    return this.namespace;
  }
  
  public A withNamespace(String namespace) {
    this.namespace = namespace;
    return (A) this;
  }
  
  public boolean hasNamespace() {
    return this.namespace != null;
  }
  
  public String getRawCNIConfig() {
    return this.rawCNIConfig;
  }
  
  public A withRawCNIConfig(String rawCNIConfig) {
    this.rawCNIConfig = rawCNIConfig;
    return (A) this;
  }
  
  public boolean hasRawCNIConfig() {
    return this.rawCNIConfig != null;
  }
  
  public SimpleMacvlanConfig buildSimpleMacvlanConfig() {
    return this.simpleMacvlanConfig != null ? this.simpleMacvlanConfig.build() : null;
  }
  
  public A withSimpleMacvlanConfig(SimpleMacvlanConfig simpleMacvlanConfig) {
    this._visitables.remove(this.simpleMacvlanConfig);
    if (simpleMacvlanConfig != null) {
        this.simpleMacvlanConfig = new SimpleMacvlanConfigBuilder(simpleMacvlanConfig);
        this._visitables.get("simpleMacvlanConfig").add(this.simpleMacvlanConfig);
    } else {
        this.simpleMacvlanConfig = null;
        this._visitables.get("simpleMacvlanConfig").remove(this.simpleMacvlanConfig);
    }
    return (A) this;
  }
  
  public boolean hasSimpleMacvlanConfig() {
    return this.simpleMacvlanConfig != null;
  }
  
  public SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfig() {
    return new SimpleMacvlanConfigNested(null);
  }
  
  public SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfigLike(SimpleMacvlanConfig item) {
    return new SimpleMacvlanConfigNested(item);
  }
  
  public SimpleMacvlanConfigNested<A> editSimpleMacvlanConfig() {
    return withNewSimpleMacvlanConfigLike(java.util.Optional.ofNullable(buildSimpleMacvlanConfig()).orElse(null));
  }
  
  public SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfig() {
    return withNewSimpleMacvlanConfigLike(java.util.Optional.ofNullable(buildSimpleMacvlanConfig()).orElse(new SimpleMacvlanConfigBuilder().build()));
  }
  
  public SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfigLike(SimpleMacvlanConfig item) {
    return withNewSimpleMacvlanConfigLike(java.util.Optional.ofNullable(buildSimpleMacvlanConfig()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AdditionalNetworkDefinitionFluent that = (AdditionalNetworkDefinitionFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(namespace, that.namespace)) return false;
    if (!java.util.Objects.equals(rawCNIConfig, that.rawCNIConfig)) return false;
    if (!java.util.Objects.equals(simpleMacvlanConfig, that.simpleMacvlanConfig)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(name,  namespace,  rawCNIConfig,  simpleMacvlanConfig,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (rawCNIConfig != null) { sb.append("rawCNIConfig:"); sb.append(rawCNIConfig + ","); }
    if (simpleMacvlanConfig != null) { sb.append("simpleMacvlanConfig:"); sb.append(simpleMacvlanConfig + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class SimpleMacvlanConfigNested<N> extends SimpleMacvlanConfigFluent<SimpleMacvlanConfigNested<N>> implements Nested<N>{
    SimpleMacvlanConfigNested(SimpleMacvlanConfig item) {
      this.builder = new SimpleMacvlanConfigBuilder(this, item);
    }
    SimpleMacvlanConfigBuilder builder;
    
    public N and() {
      return (N) AdditionalNetworkDefinitionFluent.this.withSimpleMacvlanConfig(builder.build());
    }
    
    public N endSimpleMacvlanConfig() {
      return and();
    }
    
  
  }

}

==> openshift-model-operator-6.13.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/AdditionalNetworkDefinitionFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AdditionalNetworkDefinitionFluent<A extends AdditionalNetworkDefinitionFluent<A>> extends BaseFluent<A>{
  public AdditionalNetworkDefinitionFluent() {
  }
  
  public AdditionalNetworkDefinitionFluent(AdditionalNetworkDefinition instance) {
    this.copyInstance(instance);
  }
  private String name;
  private String namespace;
  private String rawCNIConfig;
  private SimpleMacvlanConfigBuilder simpleMacvlanConfig;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(AdditionalNetworkDefinition instance) {
    instance = (instance != null ? instance : new AdditionalNetworkDefinition());
    if (instance != null) {
          this.withName(instance.getName());
          this.withNamespace(instance.getNamespace());
          this.withRawCNIConfig(instance.getRawCNIConfig());
          this.withSimpleMacvlanConfig(instance.getSimpleMacvlanConfig());
          this.withType(instance.getType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getNamespace() {
    return this.namespace;
  }
  
  public A withNamespace(String namespace) {
    this.namespace = namespace;
    return (A) this;
  }
  
  public boolean hasNamespace() {
    return this.namespace != null;
  }
  
  public String getRawCNIConfig() {
    return this.rawCNIConfig;
  }
  
  public A withRawCNIConfig(String rawCNIConfig) {
    this.rawCNIConfig = rawCNIConfig;
    return (A) this;
  }
  
  public boolean hasRawCNIConfig() {
    return this.rawCNIConfig != null;
  }
  
  public SimpleMacvlanConfig buildSimpleMacvlanConfig() {
    return this.simpleMacvlanConfig != null ? this.simpleMacvlanConfig.build() : null;
  }
  
  public A withSimpleMacvlanConfig(SimpleMacvlanConfig simpleMacvlanConfig) {
    this._visitables.remove("simpleMacvlanConfig");
    if (simpleMacvlanConfig != null) {
        this.simpleMacvlanConfig = new SimpleMacvlanConfigBuilder(simpleMacvlanConfig);
        this._visitables.get("simpleMacvlanConfig").add(this.simpleMacvlanConfig);
    } else {
        this.simpleMacvlanConfig = null;
        this._visitables.get("simpleMacvlanConfig").remove(this.simpleMacvlanConfig);
    }
    return (A) this;
  }
  
  public boolean hasSimpleMacvlanConfig() {
    return this.simpleMacvlanConfig != null;
  }
  
  public SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfig() {
    return new SimpleMacvlanConfigNested(null);
  }
  
  public SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfigLike(SimpleMacvlanConfig item) {
    return new SimpleMacvlanConfigNested(item);
  }
  
  public SimpleMacvlanConfigNested<A> editSimpleMacvlanConfig() {
    return withNewSimpleMacvlanConfigLike(java.util.Optional.ofNullable(buildSimpleMacvlanConfig()).orElse(null));
  }
  
  public SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfig() {
    return withNewSimpleMacvlanConfigLike(java.util.Optional.ofNullable(buildSimpleMacvlanConfig()).orElse(new SimpleMacvlanConfigBuilder().build()));
  }
  
  public SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfigLike(SimpleMacvlanConfig item) {
    return withNewSimpleMacvlanConfigLike(java.util.Optional.ofNullable(buildSimpleMacvlanConfig()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AdditionalNetworkDefinitionFluent that = (AdditionalNetworkDefinitionFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(namespace, that.namespace)) return false;
    if (!java.util.Objects.equals(rawCNIConfig, that.rawCNIConfig)) return false;
    if (!java.util.Objects.equals(simpleMacvlanConfig, that.simpleMacvlanConfig)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(name,  namespace,  rawCNIConfig,  simpleMacvlanConfig,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (rawCNIConfig != null) { sb.append("rawCNIConfig:"); sb.append(rawCNIConfig + ","); }
    if (simpleMacvlanConfig != null) { sb.append("simpleMacvlanConfig:"); sb.append(simpleMacvlanConfig + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class SimpleMacvlanConfigNested<N> extends SimpleMacvlanConfigFluent<SimpleMacvlanConfigNested<N>> implements Nested<N>{
    SimpleMacvlanConfigNested(SimpleMacvlanConfig item) {
      this.builder = new SimpleMacvlanConfigBuilder(this, item);
    }
    SimpleMacvlanConfigBuilder builder;
    
    public N and() {
      return (N) AdditionalNetworkDefinitionFluent.this.withSimpleMacvlanConfig(builder.build());
    }
    
    public N endSimpleMacvlanConfig() {
      return and();
    }
    
  
  }

}
